// src/sdk.ts
import "@highlight-run/opentelemetry-sdk-workers/performance";
import { OTLPProtoLogExporter } from "@highlight-run/opentelemetry-sdk-workers/exporters/OTLPProtoLogExporter";
import { OTLPProtoTraceExporter } from "@highlight-run/opentelemetry-sdk-workers/exporters/OTLPProtoTraceExporter";
import { Resource } from "@opentelemetry/resources";
import { WorkersSDK } from "@highlight-run/opentelemetry-sdk-workers";
var HIGHLIGHT_PROJECT_ENV = "HIGHLIGHT_PROJECT_ID";
var HIGHLIGHT_REQUEST_HEADER = "X-Highlight-Request";
var HIGHLIGHT_OTLP_BASE = "https://otel.highlight.io:4318";
var RECORDED_CONSOLE_METHODS = [
  "debug",
  "error",
  "info",
  "log",
  "warn"
];
var sdk;
var projectID;
var H = {
  // Initialize the highlight SDK. This monkeypatches the console methods to start sending console logs to highlight.
  init: (request, {
    [HIGHLIGHT_PROJECT_ENV]: _projectID,
    HIGHLIGHT_OTLP_ENDPOINT: otlpEndpoint
  }, ctx, service) => {
    const { secureSessionId, requestId } = extractRequestMetadata(request);
    projectID = _projectID;
    const endpoints = { default: otlpEndpoint || HIGHLIGHT_OTLP_BASE };
    sdk = new WorkersSDK(request, ctx, {
      service: service || "cloudflare-worker",
      consoleLogEnabled: false,
      traceExporter: new OTLPProtoTraceExporter({
        url: `${endpoints.default}/v1/traces`
      }),
      logExporter: new OTLPProtoLogExporter({
        url: `${endpoints.default}/v1/logs`
      }),
      // @ts-ignore
      resource: new Resource({
        ["highlight.project_id"]: projectID,
        ["highlight.session_id"]: secureSessionId,
        ["highlight.trace_id"]: requestId
      })
    });
    for (const m of RECORDED_CONSOLE_METHODS) {
      const originalConsoleMethod = console[m];
      console[m] = (message, ...args) => {
        sdk.logger[m].apply(sdk.logger, [message, ...args]);
        originalConsoleMethod.apply(originalConsoleMethod, [
          message,
          ...args
        ]);
      };
    }
    return sdk;
  },
  isInitialized: () => !!sdk,
  // Capture a javascript exception as an error in highlight.
  consumeError: (error) => {
    if (!sdk) {
      console.error(
        "please call H.init(...) before calling H.sendResponse(...)"
      );
      return;
    }
    sdk.captureException(error);
  },
  // Capture a cloudflare response as a trace in highlight.
  sendResponse: (response) => {
    if (!sdk) {
      console.error(
        "please call H.init(...) before calling H.sendResponse(...)"
      );
      return;
    }
    sdk.sendResponse(response);
  },
  // Set custom attributes on the errors and logs reported to highlight.
  // Setting a key previously set will update the value.
  setAttributes: (attributes) => {
    if (!sdk) {
      console.error(
        "please call H.init(...) before calling H.setAttributes(...)"
      );
      return;
    }
    sdk.traceProvider.resource = sdk.traceProvider.resource.merge(
      new Resource(attributes)
    );
  },
  recordMetric: ({ secureSessionId, name, value, requestId, tags }) => {
    if (!sdk.requestTracer)
      return;
    const span = sdk.requestTracer.startSpan("highlight-ctx");
    span.addEvent("metric", {
      ["highlight.project_id"]: projectID,
      ["metric.name"]: name,
      ["metric.value"]: value,
      ...secureSessionId ? {
        ["highlight.session_id"]: secureSessionId
      } : {},
      ...requestId ? {
        ["highlight.trace_id"]: requestId
      } : {}
    });
    for (const t of tags || []) {
      span.setAttribute(t.name, t.value);
    }
    span.end();
  }
};
function extractRequestMetadata(request) {
  const [secureSessionId, requestId] = (request.headers.get(HIGHLIGHT_REQUEST_HEADER) || "").split("/");
  return { secureSessionId, requestId };
}
export {
  H,
  extractRequestMetadata
};
//# sourceMappingURL=index.js.map