// src/sdk.ts
import "opentelemetry-sdk-workers/performance";
import { OTLPProtoLogExporter } from "opentelemetry-sdk-workers/exporters/OTLPProtoLogExporter";
import { OTLPProtoTraceExporter } from "opentelemetry-sdk-workers/exporters/OTLPProtoTraceExporter";
import { Resource } from "@opentelemetry/resources";
import { WorkersSDK } from "opentelemetry-sdk-workers";
var HIGHLIGHT_PROJECT_ENV = "HIGHLIGHT_PROJECT_ID";
var HIGHLIGHT_REQUEST_HEADER = "X-Highlight-Request";
var HIGHLIGHT_OTLP_BASE = "https://otel.highlight.io";
var RECORDED_CONSOLE_METHODS = [
  "debug",
  "error",
  "info",
  "log",
  "warn"
];
var sdk;
var H = {
  // Initialize the highlight SDK. This monkeypatches the console methods to start sending console logs to highlight.
  init: (request, { [HIGHLIGHT_PROJECT_ENV]: projectID }, ctx, service) => {
    const [sessionID, requestID] = (request.headers.get(HIGHLIGHT_REQUEST_HEADER) || "").split("/");
    const endpoints = { default: HIGHLIGHT_OTLP_BASE };
    sdk = new WorkersSDK(request, ctx, {
      service: service || "cloudflare-worker",
      consoleLogEnabled: false,
      traceExporter: new OTLPProtoTraceExporter({
        url: `${endpoints.default}/v1/traces`
      }),
      logExporter: new OTLPProtoLogExporter({
        url: `${endpoints.default}/v1/logs`
      }),
      resource: new Resource({
        ["highlight.project_id"]: projectID,
        ["highlight.session_id"]: sessionID,
        ["highlight.trace_id"]: requestID
      })
    });
    for (const m of RECORDED_CONSOLE_METHODS) {
      const originalConsoleMethod = console[m];
      console[m] = (message, ...args) => {
        sdk.logger[m].apply(sdk.logger, [message, ...args]);
        originalConsoleMethod.apply(originalConsoleMethod, [
          message,
          ...args
        ]);
      };
    }
    return sdk;
  },
  // Capture a javascript exception as an error in highlight.
  consumeError: (error) => {
    if (!sdk) {
      console.error(
        "please call H.init(...) before calling H.sendResponse(...)"
      );
      return;
    }
    console.log("H.consumeError", error);
    sdk.captureException(error);
  },
  // Capture a cloudflare response as a trace in highlight.
  sendResponse: (response) => {
    if (!sdk) {
      console.error(
        "please call H.init(...) before calling H.sendResponse(...)"
      );
      return;
    }
    sdk.sendResponse(response);
  },
  // Set custom attributes on the errors and logs reported to highlight.
  // Setting a key previously set will update the value.
  setAttributes: (attributes) => {
    if (!sdk) {
      console.error(
        "please call H.init(...) before calling H.setAttributes(...)"
      );
      return;
    }
    sdk.traceProvider.resource = sdk.traceProvider.resource.merge(
      new Resource(attributes)
    );
  }
};
export {
  H
};
